@@ -2,4 +2,7 @@ from .ConceptsExtractor import ConceptsExtractor
 from .CustomConceptsExtractor import CustomConceptsExtractor
 from .EntitiesExtractor import EntitiesExtractor
 from .IntentClassifier import IntentClassifier
+from .DucklingExtractor import DucklingExtractor
+from .PhraseMatcherExtractor import PhraseMatcherExtractor
+
 
