@@ -1,3 +1,3 @@
 from .Client import Client
-from .Multi import Pipeline
+from .Multi import Pipeline, Bulk
 from . import ApiModels, Errors
